github-actions[bot] wrote:

<!--PREMERGE ADVISOR COMMENT: Linux-->
# :penguin: Linux x64 Test Results

* 61941 tests passed
* 2073 tests skipped
* 3 tests failed

## Failed Tests
(click on a test name to see its output)

### Clang
<details>
<summary>Clang.CodeGenCUDA/cluster_dims.cu</summary>

```
Exit Code: 2

Command Output (stdout):
--
# RUN: at line 1
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -emit-llvm -x 
hip -o - 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu
 | /home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/FileCheck 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -emit-llvm -x 
hip -o - 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu
# .---command stderr------------
# | clang: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:335:
 void assertAPValueKind(const ConstantExpr *, const APValue &): Assertion 
`(V.isLValue() || V.isArray()) && "a lvalue ConstantExpr needs an lvalue 
APValue"' failed.
# | PLEASE submit a bug report to https://github.com/llvm/llvm-project/issues/ 
and include the crash backtrace and dumped files.
# | Stack dump:
# | 0.  Program arguments: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -emit-llvm -x 
hip -o - 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu
# | 1.  
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu:20:77:
 current parser token '{'
# |  #0 0x00000000098b4f8b llvm::sys::PrintStackTrace(llvm::raw_ostream&, int) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:931:13
# |  #1 0x00000000098b1e21 llvm::sys::RunSignalHandlers() 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Signals.cpp:109:18
# |  #2 0x00000000098b59cb SignalHandler(int, siginfo_t*, void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:474:38
# |  #3 0x00000000098b5838 SignalHandlerTerminate(int, siginfo_t*, void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:0:3
# |  #4 0x00007b4a61d0bcb0 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x45cb0)
# |  #5 0x00007b4a61d6c1ac pthread_kill 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0xa61ac)
# |  #6 0x00007b4a61d0bb7e raise (/usr/lib/x86_64-linux-gnu/libc.so.6+0x45b7e)
# |  #7 0x00007b4a61cee8ec abort (/usr/lib/x86_64-linux-gnu/libc.so.6+0x288ec)
# |  #8 0x00007b4a61cef979 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x29979)
# |  #9 0x00007b4a61d01f75 __assert_fail 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0x3bf75)
# | #10 0x000000000cd0513e clang::ConstantExpr::MoveIntoResult(clang::APValue&, 
clang::ASTContext const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:458:3
# | #11 0x000000000cd04f65 ~APValue 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/AST/APValue.h:517:22
# | #12 0x000000000cd04f65 clang::ConstantExpr::Create(clang::ASTContext 
const&, clang::Expr*, clang::APValue const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:431:3
# | #13 0x000000000c09f7c1 operator-> 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/optional:1172:2
# | #14 0x000000000c09f7c1 makeClusterDimsArgExpr(clang::Sema&, clang::Expr*, 
clang::CUDAClusterDimsAttr const&, unsigned int) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6212:11
# | #15 0x000000000c09f3c2 
clang::Sema::createClusterDimsAttr(clang::AttributeCommonInfo const&, 
clang::Expr*, clang::Expr*, clang::Expr*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6219:23
# | #16 0x000000000c0b1e84 addClusterDimsAttr 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6251:13
# | #17 0x000000000c0b1e84 handleClusterDimsAttr(clang::Sema&, clang::Decl*, 
clang::ParsedAttr const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6274:5
# | #18 0x000000000c0a1333 operator== 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/iterator.h:300:18
# | #19 0x000000000c0a1333 operator!= 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/iterator.h:184:51
# | #20 0x000000000c0a1333 clang::Sema::ProcessDeclAttributeList(clang::Scope*, 
clang::Decl*, clang::ParsedAttributesView const&, 
clang::Sema::ProcessDeclAttributeOptions const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:8587:29
# | #21 0x000000000c0a7363 begin 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:276:45
# | #22 0x000000000c0a7363 end 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:278:27
# | #23 0x000000000c0a7363 ~SmallVector 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:1258:46
# | #24 0x000000000c0a7363 ~ParsedAttributesView 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Sema/ParsedAttr.h:822:7
# | #25 0x000000000c0a7363 clang::Sema::ProcessDeclAttributes(clang::Scope*, 
clang::Decl*, clang::Declarator 
const&)::$_0::operator()(clang::ParsedAttributesView const&, 
clang::Sema::ProcessDeclAttributeOptions const&) const 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:8905:7
# | #26 0x000000000c0a715c size 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:83:32
# | #27 0x000000000c0a715c getNumTypeObjects 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Sema/DeclSpec.h:2449:60
# | #28 0x000000000c0a715c clang::Sema::ProcessDeclAttributes(clang::Scope*, 
clang::Decl*, clang::Declarator const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:8921:31
# | #29 0x000000000c03cb88 clang::Sema::ActOnFunctionDeclarator(clang::Scope*, 
clang::Declarator&, clang::DeclContext*, clang::TypeSourceInfo*, 
clang::LookupResult&, llvm::MutableArrayRef<clang::TemplateParameterList*>, 
bool&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:10886:32
# | #30 0x000000000c0398bb clang::Sema::HandleDeclarator(clang::Scope*, 
clang::Declarator&, llvm::MutableArrayRef<clang::TemplateParameterList*>) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:0:11
# | #31 0x000000000c05e9bc clang::Sema::ActOnStartOfFunctionDef(clang::Scope*, 
clang::Declarator&, llvm::MutableArrayRef<clang::TemplateParameterList*>, 
clang::SkipBodyInfo*, clang::Sema::FnBodyKind) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:16283:15
# | #32 0x000000000bcea667 
clang::Parser::ParseFunctionDefinition(clang::ParsingDeclarator&, 
clang::Parser::ParsedTemplateInfo const&, clang::LateParsedAttrList*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1347:23
# | #33 0x000000000bd58b82 
clang::Parser::ParseDeclGroup(clang::ParsingDeclSpec&, 
clang::DeclaratorContext, clang::ParsedAttributes&, 
clang::Parser::ParsedTemplateInfo&, clang::SourceLocation*, 
clang::Parser::ForRangeInit*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseDecl.cpp:2296:18
# | #34 0x000000000bce9734 
clang::Parser::ParseDeclOrFunctionDefInternal(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec&, clang::AccessSpecifier) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:0:10
# | #35 0x000000000bce8f4a 
clang::Parser::ParseDeclarationOrFunctionDefinition(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec*, clang::AccessSpecifier) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1186:12
# | #36 0x000000000bce80bb 
clang::Parser::ParseExternalDeclaration(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1014:14
# | #37 0x000000000bce6510 
clang::Parser::ParseTopLevelDecl(clang::OpaquePtr<clang::DeclGroupRef>&, 
clang::Sema::ModuleImportState&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:723:10
# | #38 0x000000000bcd9bfe clang::ParseAST(clang::Sema&, bool, bool) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseAST.cpp:164:5
# | #39 0x000000000a79cd26 clang::FrontendAction::Execute() 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Frontend/FrontendAction.cpp:1381:10
# | #40 0x000000000a7100d9 getPtr 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/Support/Error.h:278:42
# | #41 0x000000000a7100d9 operator bool 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/Support/Error.h:241:16
# | #42 0x000000000a7100d9 
clang::CompilerInstance::ExecuteAction(clang::FrontendAction&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Frontend/CompilerInstance.cpp:1040:23
# | #43 0x000000000a8617cd get 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1673:16
# | #44 0x000000000a8617cd _M_get 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1370:66
# | #45 0x000000000a8617cd operator-> 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1364:9
# | #46 0x000000000a8617cd getFrontendOpts 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Frontend/CompilerInstance.h:324:12
# | #47 0x000000000a8617cd 
clang::ExecuteCompilerInvocation(clang::CompilerInstance*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/FrontendTool/ExecuteCompilerInvocation.cpp:327:14
# | #48 0x0000000006919ca5 cc1_main(llvm::ArrayRef<char const*>, char const*, 
void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/cc1_main.cpp:296:13
# | #49 0x00000000069158b3 ExecuteCC1Tool(llvm::SmallVectorImpl<char const*>&, 
llvm::ToolContext const&, llvm::IntrusiveRefCntPtr<llvm::vfs::FileSystem>) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/driver.cpp:229:12
# | #50 0x00000000069148e3 clang_main(int, char**, llvm::ToolContext const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/driver.cpp:277:12
# | #51 0x0000000006925486 main 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/tools/clang/tools/driver/clang-driver.cpp:17:10
# | #52 0x00007b4a61cf0601 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x2a601)
# | #53 0x00007b4a61cf0718 __libc_start_main 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0x2a718)
# | #54 0x0000000006913325 _start 
(/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang+0x6913325)
# `-----------------------------
# error: command failed with exit status: -6
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/FileCheck 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu
# .---command stderr------------
# | FileCheck error: '<stdin>' is empty.
# | FileCheck command line:  
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/FileCheck 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/CodeGenCUDA/cluster_dims.cu
# `-----------------------------
# error: command failed with exit status: 2

--

```
</details>
<details>
<summary>Clang.Sema/i-c-e.c</summary>

```
Exit Code: -6

Command Output (stdout):
--
# RUN: at line 1
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/Sema/i-c-e.c
 -ffreestanding -Wno-int-to-pointer-cast -fsyntax-only -verify -pedantic 
-fpascal-strings -std=c99
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/Sema/i-c-e.c
 -ffreestanding -Wno-int-to-pointer-cast -fsyntax-only -verify -pedantic 
-fpascal-strings -std=c99
# .---command stderr------------
# | clang: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:342:
 void assertAPValueKind(const ConstantExpr *, const APValue &): Assertion 
`(V.isInt() || V.isAddrLabelDiff()) && "a ConstantExpr of integer type needs an 
int APValue result"' failed.
# | PLEASE submit a bug report to https://github.com/llvm/llvm-project/issues/ 
and include the crash backtrace and dumped files.
# | Stack dump:
# | 0.  Program arguments: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/Sema/i-c-e.c
 -ffreestanding -Wno-int-to-pointer-cast -fsyntax-only -verify -pedantic 
-fpascal-strings -std=c99
# | 1.  
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/Sema/i-c-e.c:80:57:
 current parser token ';'
# |  #0 0x00000000098b4f8b llvm::sys::PrintStackTrace(llvm::raw_ostream&, int) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:931:13
# |  #1 0x00000000098b1e21 llvm::sys::RunSignalHandlers() 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Signals.cpp:109:18
# |  #2 0x00000000098b59cb SignalHandler(int, siginfo_t*, void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:474:38
# |  #3 0x00000000098b5838 SignalHandlerTerminate(int, siginfo_t*, void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:0:3
# |  #4 0x00007cb20537bcb0 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x45cb0)
# |  #5 0x00007cb2053dc1ac pthread_kill 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0xa61ac)
# |  #6 0x00007cb20537bb7e raise (/usr/lib/x86_64-linux-gnu/libc.so.6+0x45b7e)
# |  #7 0x00007cb20535e8ec abort (/usr/lib/x86_64-linux-gnu/libc.so.6+0x288ec)
# |  #8 0x00007cb20535f979 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x29979)
# |  #9 0x00007cb205371f75 __assert_fail 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0x3bf75)
# | #10 0x000000000cd05189 getTypePtr 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/AST/TypeBase.h:8447:26
# | #11 0x000000000cd05189 operator-> 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/AST/TypeBase.h:998:12
# | #12 0x000000000cd05189 assertAPValueKind 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:346:7
# | #13 0x000000000cd05189 clang::ConstantExpr::MoveIntoResult(clang::APValue&, 
clang::ASTContext const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:458:3
# | #14 0x000000000cd04f65 ~APValue 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/AST/APValue.h:517:22
# | #15 0x000000000cd04f65 clang::ConstantExpr::Create(clang::ASTContext 
const&, clang::Expr*, clang::APValue const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:431:3
# | #16 0x000000000c198f53 
clang::Sema::VerifyIntegerConstantExpression(clang::Expr*, llvm::APSInt*, 
clang::Sema::VerifyICEDiagnoser&, clang::AllowFoldKind) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaExpr.cpp:18334:9
# | #17 0x000000000c7570ce checkArraySize(clang::Sema&, clang::Expr*&, 
llvm::APSInt&, unsigned int, bool) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaType.cpp:2071:7
# | #18 0x000000000c75673a clang::Sema::BuildArrayType(clang::QualType, 
clang::ArraySizeModifier, clang::Expr*, unsigned int, clang::SourceRange, 
clang::DeclarationName) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaType.cpp:2290:11
# | #19 0x000000000c75d334 GetFullTypeForDeclarator((anonymous 
namespace)::TypeProcessingState&, clang::QualType, clang::TypeSourceInfo*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaType.cpp:4915:13
# | #20 0x000000000c75a0e7 
clang::Sema::GetTypeForDeclarator(clang::Declarator&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaType.cpp:5817:10
# | #21 0x000000000c039154 clang::Sema::HandleDeclarator(clang::Scope*, 
clang::Declarator&, llvm::MutableArrayRef<clang::TemplateParameterList*>) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:6624:27
# | #22 0x000000000c038daa clang::Sema::ActOnDeclarator(clang::Scope*, 
clang::Declarator&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:6374:15
# | #23 0x000000000bd59d05 
clang::Parser::ParseDeclarationAfterDeclaratorAndAttributes(clang::Declarator&, 
clang::Parser::ParsedTemplateInfo const&, clang::Parser::ForRangeInit*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseDecl.cpp:0:0
# | #24 0x000000000bd580b3 
clang::Parser::ParseDeclGroup(clang::ParsingDeclSpec&, 
clang::DeclaratorContext, clang::ParsedAttributes&, 
clang::Parser::ParsedTemplateInfo&, clang::SourceLocation*, 
clang::Parser::ForRangeInit*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseDecl.cpp:2379:7
# | #25 0x000000000bce9734 
clang::Parser::ParseDeclOrFunctionDefInternal(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec&, clang::AccessSpecifier) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:0:10
# | #26 0x000000000bce8f4a 
clang::Parser::ParseDeclarationOrFunctionDefinition(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec*, clang::AccessSpecifier) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1186:12
# | #27 0x000000000bce80bb 
clang::Parser::ParseExternalDeclaration(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1014:14
# | #28 0x000000000bce6510 
clang::Parser::ParseTopLevelDecl(clang::OpaquePtr<clang::DeclGroupRef>&, 
clang::Sema::ModuleImportState&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:723:10
# | #29 0x000000000bcd9bfe clang::ParseAST(clang::Sema&, bool, bool) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseAST.cpp:164:5
# | #30 0x000000000a79cd26 clang::FrontendAction::Execute() 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Frontend/FrontendAction.cpp:1381:10
# | #31 0x000000000a7100d9 getPtr 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/Support/Error.h:278:42
# | #32 0x000000000a7100d9 operator bool 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/Support/Error.h:241:16
# | #33 0x000000000a7100d9 
clang::CompilerInstance::ExecuteAction(clang::FrontendAction&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Frontend/CompilerInstance.cpp:1040:23
# | #34 0x000000000a8617cd get 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1673:16
# | #35 0x000000000a8617cd _M_get 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1370:66
# | #36 0x000000000a8617cd operator-> 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1364:9
# | #37 0x000000000a8617cd getFrontendOpts 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Frontend/CompilerInstance.h:324:12
# | #38 0x000000000a8617cd 
clang::ExecuteCompilerInvocation(clang::CompilerInstance*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/FrontendTool/ExecuteCompilerInvocation.cpp:327:14
# | #39 0x0000000006919ca5 cc1_main(llvm::ArrayRef<char const*>, char const*, 
void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/cc1_main.cpp:296:13
# | #40 0x00000000069158b3 ExecuteCC1Tool(llvm::SmallVectorImpl<char const*>&, 
llvm::ToolContext const&, llvm::IntrusiveRefCntPtr<llvm::vfs::FileSystem>) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/driver.cpp:229:12
# | #41 0x00000000069148e3 clang_main(int, char**, llvm::ToolContext const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/driver.cpp:277:12
# | #42 0x0000000006925486 main 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/tools/clang/tools/driver/clang-driver.cpp:17:10
# | #43 0x00007cb205360601 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x2a601)
# | #44 0x00007cb205360718 __libc_start_main 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0x2a718)
# | #45 0x0000000006913325 _start 
(/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang+0x6913325)
# `-----------------------------
# error: command failed with exit status: -6

--

```
</details>
<details>
<summary>Clang.SemaCUDA/cluster_dims.cu</summary>

```
Exit Code: 2

Command Output (stdout):
--
# RUN: at line 1
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu-amd-amdhsa -fcuda-is-device -ast-print -x hip 
-verify=NS,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu-amd-amdhsa -fcuda-is-device -ast-print -x hip 
-verify=NS,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# .---command stdout------------
# | typedef long ptrdiff_t;
# | typedef unsigned long size_t;
# | typedef struct  {
# |     long long __clang_max_align_nonce1 
__attribute__((aligned(__alignof(long long))));
# |     long double __clang_max_align_nonce2 
__attribute__((aligned(__alignof(long double))));
# | } max_align_t;
# | struct dim3 {
# |     unsigned int x;
# |     unsigned int y;
# |     unsigned int z;
# |     __attribute__((host)) __attribute__((device)) dim3(unsigned int x, 
unsigned int y = 1, unsigned int z = 1) : x(x), y(y), z(z) {
# |     }
# | };
# | typedef struct hipStream *hipStream_t;
# | typedef enum hipError {
# | } hipError_t;
# | int hipConfigureCall(dim3 gridSize, dim3 blockSize, size_t sharedSize = 0, 
hipStream_t stream = 0);
# | extern "C" hipError_t __hipPushCallConfiguration(dim3 gridSize, dim3 
blockSize, size_t sharedSize = 0, hipStream_t stream = 0)
# | extern "C" hipError_t hipLaunchKernel(const void *func, dim3 gridDim, dim3 
blockDim, void **args, size_t sharedMem, hipStream_t stream)
# | void *operator new(unsigned long, void *p) {
# |     return p;
# | }
# | void *operator new[](unsigned long, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new(unsigned long, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new[](unsigned long, void *p) {
# |     return p;
# | }
# | const int constint = 4;
# | __attribute__((global)) void test_literal_3d() {
# | }
# | __attribute__((global)) void test_literal_2d() {
# | }
# | __attribute__((global)) void test_literal_1d() {
# | }
# | __attribute__((global)) void test_constant() {
# | }
# | template <int x, int y, int z> void test_template() {
# | }
# | template <int x, int y, int z> void test_template_expr() {
# | }
# | __attribute__((global)) void test_too_large_dim_0() {
# | }
# | __attribute__((global)) void test_too_large_dim_1() {
# | }
# | template <unsigned int a, unsigned int b, unsigned int c> void 
test_too_large_dim_template() {
# | }
# | template void test_too_large_dim_template<4, 4, 4>();
# | int none_const_int = 4;
# | __attribute__((global)) void test_non_constant_0() {
# | }
# | __attribute__((global)) void test_non_constant_1() {
# | }
# | __attribute__((global)) void test_non_constant_2() {
# | }
# | __attribute__((global)) void test_no_cluster() {
# | }
# | __attribute__((global)) void test_have_both() {
# | }
# | template <int ...args> void test_template_variadic_args() {
# | }
# | template <int ...args> void test_template_variadic_args_2() {
# | }
# `-----------------------------
# RUN: at line 2
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple nvptx-nvidia-cuda -fcuda-is-device -ast-print -x hip 
-verify=NS,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple nvptx-nvidia-cuda -fcuda-is-device -ast-print -x hip 
-verify=NS,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# .---command stdout------------
# | typedef int ptrdiff_t;
# | typedef unsigned int size_t;
# | typedef struct  {
# |     long long __clang_max_align_nonce1 
__attribute__((aligned(__alignof(long long))));
# |     long double __clang_max_align_nonce2 
__attribute__((aligned(__alignof(long double))));
# | } max_align_t;
# | struct dim3 {
# |     unsigned int x;
# |     unsigned int y;
# |     unsigned int z;
# |     __attribute__((host)) __attribute__((device)) dim3(unsigned int x, 
unsigned int y = 1, unsigned int z = 1) : x(x), y(y), z(z) {
# |     }
# | };
# | typedef struct hipStream *hipStream_t;
# | typedef enum hipError {
# | } hipError_t;
# | int hipConfigureCall(dim3 gridSize, dim3 blockSize, size_t sharedSize = 0, 
hipStream_t stream = 0);
# | extern "C" hipError_t __hipPushCallConfiguration(dim3 gridSize, dim3 
blockSize, size_t sharedSize = 0, hipStream_t stream = 0)
# | extern "C" hipError_t hipLaunchKernel(const void *func, dim3 gridDim, dim3 
blockDim, void **args, size_t sharedMem, hipStream_t stream)
# | void *operator new(unsigned int, void *p) {
# |     return p;
# | }
# | void *operator new[](unsigned int, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new(unsigned int, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new[](unsigned int, void *p) {
# |     return p;
# | }
# | const int constint = 4;
# | __attribute__((global)) void test_literal_3d() {
# | }
# | __attribute__((global)) void test_literal_2d() {
# | }
# | __attribute__((global)) void test_literal_1d() {
# | }
# | __attribute__((global)) void test_constant() {
# | }
# | template <int x, int y, int z> void test_template() {
# | }
# | template <int x, int y, int z> void test_template_expr() {
# | }
# | __attribute__((global)) void test_too_large_dim_0() {
# | }
# | __attribute__((global)) void test_too_large_dim_1() {
# | }
# | template <unsigned int a, unsigned int b, unsigned int c> void 
test_too_large_dim_template() {
# | }
# | template void test_too_large_dim_template<4, 4, 4>();
# | int none_const_int = 4;
# | __attribute__((global)) void test_non_constant_0() {
# | }
# | __attribute__((global)) void test_non_constant_1() {
# | }
# | __attribute__((global)) void test_non_constant_2() {
# | }
# | __attribute__((global)) void test_no_cluster() {
# | }
# | __attribute__((global)) void test_have_both() {
# | }
# | template <int ...args> void test_template_variadic_args() {
# | }
# | template <int ...args> void test_template_variadic_args_2() {
# | }
# `-----------------------------
# RUN: at line 3
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -ast-print -x 
hip -verify=amd,common,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
 | /home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/FileCheck 
-check-prefixes=CHECK 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -ast-print -x 
hip -verify=amd,common,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# .---command stderr------------
# | clang: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:335:
 void assertAPValueKind(const ConstantExpr *, const APValue &): Assertion 
`(V.isLValue() || V.isArray()) && "a lvalue ConstantExpr needs an lvalue 
APValue"' failed.
# | PLEASE submit a bug report to https://github.com/llvm/llvm-project/issues/ 
and include the crash backtrace and dumped files.
# | Stack dump:
# | 0.  Program arguments: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang -cc1 
-internal-isystem 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/lib/clang/24/include
 -nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -ast-print -x 
hip -verify=amd,common,all 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# | 1.  
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu:21:77:
 current parser token '{'
# |  #0 0x00000000098b4f8b llvm::sys::PrintStackTrace(llvm::raw_ostream&, int) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:931:13
# |  #1 0x00000000098b1e21 llvm::sys::RunSignalHandlers() 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Signals.cpp:109:18
# |  #2 0x00000000098b59cb SignalHandler(int, siginfo_t*, void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:474:38
# |  #3 0x00000000098b5838 SignalHandlerTerminate(int, siginfo_t*, void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/lib/Support/Unix/Signals.inc:0:3
# |  #4 0x00007f4e337b0cb0 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x45cb0)
# |  #5 0x00007f4e338111ac pthread_kill 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0xa61ac)
# |  #6 0x00007f4e337b0b7e raise (/usr/lib/x86_64-linux-gnu/libc.so.6+0x45b7e)
# |  #7 0x00007f4e337938ec abort (/usr/lib/x86_64-linux-gnu/libc.so.6+0x288ec)
# |  #8 0x00007f4e33794979 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x29979)
# |  #9 0x00007f4e337a6f75 __assert_fail 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0x3bf75)
# | #10 0x000000000cd0513e clang::ConstantExpr::MoveIntoResult(clang::APValue&, 
clang::ASTContext const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:458:3
# | #11 0x000000000cd04f65 ~APValue 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/AST/APValue.h:517:22
# | #12 0x000000000cd04f65 clang::ConstantExpr::Create(clang::ASTContext 
const&, clang::Expr*, clang::APValue const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/AST/Expr.cpp:431:3
# | #13 0x000000000c09f7c1 operator-> 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/optional:1172:2
# | #14 0x000000000c09f7c1 makeClusterDimsArgExpr(clang::Sema&, clang::Expr*, 
clang::CUDAClusterDimsAttr const&, unsigned int) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6212:11
# | #15 0x000000000c09f3c2 
clang::Sema::createClusterDimsAttr(clang::AttributeCommonInfo const&, 
clang::Expr*, clang::Expr*, clang::Expr*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6219:23
# | #16 0x000000000c0b1e84 addClusterDimsAttr 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6251:13
# | #17 0x000000000c0b1e84 handleClusterDimsAttr(clang::Sema&, clang::Decl*, 
clang::ParsedAttr const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:6274:5
# | #18 0x000000000c0a1333 operator== 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/iterator.h:300:18
# | #19 0x000000000c0a1333 operator!= 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/iterator.h:184:51
# | #20 0x000000000c0a1333 clang::Sema::ProcessDeclAttributeList(clang::Scope*, 
clang::Decl*, clang::ParsedAttributesView const&, 
clang::Sema::ProcessDeclAttributeOptions const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:8587:29
# | #21 0x000000000c0a7363 begin 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:276:45
# | #22 0x000000000c0a7363 end 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:278:27
# | #23 0x000000000c0a7363 ~SmallVector 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:1258:46
# | #24 0x000000000c0a7363 ~ParsedAttributesView 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Sema/ParsedAttr.h:822:7
# | #25 0x000000000c0a7363 clang::Sema::ProcessDeclAttributes(clang::Scope*, 
clang::Decl*, clang::Declarator 
const&)::$_0::operator()(clang::ParsedAttributesView const&, 
clang::Sema::ProcessDeclAttributeOptions const&) const 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:8905:7
# | #26 0x000000000c0a715c size 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/ADT/SmallVector.h:83:32
# | #27 0x000000000c0a715c getNumTypeObjects 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Sema/DeclSpec.h:2449:60
# | #28 0x000000000c0a715c clang::Sema::ProcessDeclAttributes(clang::Scope*, 
clang::Decl*, clang::Declarator const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDeclAttr.cpp:8921:31
# | #29 0x000000000c03cb88 clang::Sema::ActOnFunctionDeclarator(clang::Scope*, 
clang::Declarator&, clang::DeclContext*, clang::TypeSourceInfo*, 
clang::LookupResult&, llvm::MutableArrayRef<clang::TemplateParameterList*>, 
bool&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:10886:32
# | #30 0x000000000c0398bb clang::Sema::HandleDeclarator(clang::Scope*, 
clang::Declarator&, llvm::MutableArrayRef<clang::TemplateParameterList*>) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:0:11
# | #31 0x000000000c05e9bc clang::Sema::ActOnStartOfFunctionDef(clang::Scope*, 
clang::Declarator&, llvm::MutableArrayRef<clang::TemplateParameterList*>, 
clang::SkipBodyInfo*, clang::Sema::FnBodyKind) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Sema/SemaDecl.cpp:16283:15
# | #32 0x000000000bcea667 
clang::Parser::ParseFunctionDefinition(clang::ParsingDeclarator&, 
clang::Parser::ParsedTemplateInfo const&, clang::LateParsedAttrList*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1347:23
# | #33 0x000000000bd58b82 
clang::Parser::ParseDeclGroup(clang::ParsingDeclSpec&, 
clang::DeclaratorContext, clang::ParsedAttributes&, 
clang::Parser::ParsedTemplateInfo&, clang::SourceLocation*, 
clang::Parser::ForRangeInit*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseDecl.cpp:2296:18
# | #34 0x000000000bce9734 
clang::Parser::ParseDeclOrFunctionDefInternal(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec&, clang::AccessSpecifier) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:0:10
# | #35 0x000000000bce8f4a 
clang::Parser::ParseDeclarationOrFunctionDefinition(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec*, clang::AccessSpecifier) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1186:12
# | #36 0x000000000bce80bb 
clang::Parser::ParseExternalDeclaration(clang::ParsedAttributes&, 
clang::ParsedAttributes&, clang::ParsingDeclSpec*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:1014:14
# | #37 0x000000000bce6510 
clang::Parser::ParseTopLevelDecl(clang::OpaquePtr<clang::DeclGroupRef>&, 
clang::Sema::ModuleImportState&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/Parser.cpp:723:10
# | #38 0x000000000bcd9bfe clang::ParseAST(clang::Sema&, bool, bool) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Parse/ParseAST.cpp:164:5
# | #39 0x000000000a79cd26 clang::FrontendAction::Execute() 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Frontend/FrontendAction.cpp:1381:10
# | #40 0x000000000a7100d9 getPtr 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/Support/Error.h:278:42
# | #41 0x000000000a7100d9 operator bool 
/home/gha/actions-runner/_work/llvm-project/llvm-project/llvm/include/llvm/Support/Error.h:241:16
# | #42 0x000000000a7100d9 
clang::CompilerInstance::ExecuteAction(clang::FrontendAction&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/Frontend/CompilerInstance.cpp:1040:23
# | #43 0x000000000a8617cd get 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1673:16
# | #44 0x000000000a8617cd _M_get 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1370:66
# | #45 0x000000000a8617cd operator-> 
/usr/lib/gcc/x86_64-linux-gnu/15/../../../../include/c++/15/bits/shared_ptr_base.h:1364:9
# | #46 0x000000000a8617cd getFrontendOpts 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/include/clang/Frontend/CompilerInstance.h:324:12
# | #47 0x000000000a8617cd 
clang::ExecuteCompilerInvocation(clang::CompilerInstance*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/lib/FrontendTool/ExecuteCompilerInvocation.cpp:327:14
# | #48 0x0000000006919ca5 cc1_main(llvm::ArrayRef<char const*>, char const*, 
void*) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/cc1_main.cpp:296:13
# | #49 0x00000000069158b3 ExecuteCC1Tool(llvm::SmallVectorImpl<char const*>&, 
llvm::ToolContext const&, llvm::IntrusiveRefCntPtr<llvm::vfs::FileSystem>) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/driver.cpp:229:12
# | #50 0x00000000069148e3 clang_main(int, char**, llvm::ToolContext const&) 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/tools/driver/driver.cpp:277:12
# | #51 0x0000000006925486 main 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/tools/clang/tools/driver/clang-driver.cpp:17:10
# | #52 0x00007f4e33795601 (/usr/lib/x86_64-linux-gnu/libc.so.6+0x2a601)
# | #53 0x00007f4e33795718 __libc_start_main 
(/usr/lib/x86_64-linux-gnu/libc.so.6+0x2a718)
# | #54 0x0000000006913325 _start 
(/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/clang+0x6913325)
# `-----------------------------
# error: command failed with exit status: -6
# executed command: 
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/FileCheck 
-check-prefixes=CHECK 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# .---command stderr------------
# | FileCheck error: '<stdin>' is empty.
# | FileCheck command line:  
/home/gha/actions-runner/_work/llvm-project/llvm-project/build/bin/FileCheck 
-check-prefixes=CHECK 
/home/gha/actions-runner/_work/llvm-project/llvm-project/clang/test/SemaCUDA/cluster_dims.cu
# `-----------------------------
# error: command failed with exit status: 2

--

```
</details>

If these failures are unrelated to your changes (for example tests are broken 
or flaky at HEAD), please open an issue at 
https://github.com/llvm/llvm-project/issues and add the `infrastructure` label.

https://github.com/llvm/llvm-project/pull/230388
_______________________________________________
cfe-commits mailing list
[email protected]
https://lists.llvm.org/cgi-bin/mailman/listinfo/cfe-commits

Reply via email to